/*
  Text List
    あかつきみさき（みくちぃP）

  このスクリプトについて
    選択したテキストレイヤーのソーステキストに,クリックしたリストのテキストを流し込むスクリプト.
    「Import Text」ボタンでテキストファイルを読み込み,リスト選択して適用します.

  使用方法
    「ScriptUI Panels」フォルダーに入れてスクリプトを実行.

  動作環境
    Adobe After Effects CS6以上

  バージョン情報
    2018/03/04 Ver 1.0.0 Release
*/

/// <reference path="C:\Users\RUI\OneDrive\lib\aftereffects.d.ts\ae.d.ts"/>

(function () {
    const data = {
        scriptName: "Text List",
        version: 1.0
    }

    const isCompActive = function (comp: CompItem): boolean {
        if (!(comp && comp instanceof CompItem)) {
            return false;
        } else {
            return true;
        }
    }

    const isLayerSelected = function (layers: Layer[]): boolean {
        if (layers.length === 0) {
            return false;
        } else {
            return true;
        }
    }

    Property.prototype.setValueAtSmart = function (time: number, newValue: any) {
        try {
            if (this.numKeys === 0) {
                return this.setValue(newValue);
            } else {
                return this.setValueAtTime(time, newValue);
            }
        } catch (err) {
        }
    }

    let buildUI = function (thisObj) {
        let result = null;

        let myWindow = (thisObj instanceof Panel ? thisObj : new Window("palette", "Text List", undefined, { resizeable: true }));
        myWindow.alignment = ["fill", "top"];
        myWindow.spacing = 1;
        myWindow.margins = [0, 0, 0, 0];

        let topGrp = myWindow.add("group");
        topGrp.spacing = 1;
        topGrp.margins = [1, 1, 1, 1];
        topGrp.orientation = "row";
        topGrp.alignment = ["fill", "top"];
        let importBtn = topGrp.add("button");
        importBtn.text = "Import Text"
        importBtn.alignment = ["fill", "fill"];
        let listGrp = myWindow.add("group");
        listGrp.spacing = 1;
        listGrp.margins = [1, 1, 1, 1];
        listGrp.orientation = "row";
        listGrp.alignment = ["fill", "fill"];

        let textList = listGrp.add("listbox");
        textList.alignment = ["fill", "fill"];

        importBtn.onClick = function () {
            let textFile = new File(Folder.desktop).openDlg("");
            if (!textFile) {
                return;
            }

            textFile.open("r");
            let text = textFile.read().split("\n");
            textFile.close();

            if (text.length != 0) {
                textList.removeAll();
            }

            for (let i = 0; i < text.length; i++) {
                if (text[i] == "") {
                    continue;
                }

                textList.add("item", text[i]);
            }
        }

        textList.onChange = function () {
            if (this.selection == null) {
                return 0;
            }

            const actComp: CompItem = app.project.activeItem as CompItem;
            if (!isCompActive(actComp)) {
                this.selection = null;
                return 0;
            }

            const selLayers: Layer[] = actComp.selectedLayers as Layer[];
            if (!isLayerSelected(selLayers)) {
                actComp.layers.addText(new TextDocument(this.selection.text));
                this.selection = null;
                return 0;
            }

            app.beginUndoGroup("Text List");
            for (let i = 0; i < selLayers.length; i++) {
                if (!(selLayers[i] instanceof TextLayer)) {
                    continue;
                }

                selLayers[i].property("ADBE Text Properties").property("ADBE Text Document").setValueAtSmart(actComp.time, this.selection.text);
            }
            app.endUndoGroup();

            this.selection = null;
        }

        myWindow.layout.layout(true);
        myWindow.layout.resize();
        myWindow.onResizing = myWindow.onResize = function () {
            myWindow.layout.resize();
            return 0;
        };

        if (!(thisObj instanceof Panel)) {
            myWindow.show();
        }
        return result;
    }

    buildUI(this);
    return 0;
}).call(this);
